class main {
	static k = /*#__PURE__*/ V();
	static [/*#__PURE__*/ W()];
}

export { main as default };
